@@ -8,12 +8,43 @@ FBP::Perl - Generate Perl GUI code from wxFormBuilder .fbp files
 
 =head1 SYNOPSIS
 
+  my $fbp = FBP->new;
+  $fbp->parse_file( 'MyProject.fbp' );
+  
   my $generator = FBP::Perl->new(
-      dialog => $fbp_object->dialog('MyDialog')
+      project => $fbp->project
   );
+  
+  open( FILE, '>', 'MyDialog.pm');
+  print $generator->flatten(
+      $generator->dialog_class(
+          $fbp->dialog('MyDialog')
+      )
+  );
+  close FILE;
 
 =head1 DESCRIPTION
 
+B<FBP::Perl> is a cross-platform Perl code generator for the cross-platform
+L<wxFormBuilder|http://wxformbuilder.org/> GUI designer application.
+
+Used with the L<FBP> module for parsing native wxFormBuilder save files, it
+allows the production of complete standalone classes representing a complete
+L<Wx> dialog, frame or panel as it appears in wxFormBuilder.
+
+As code generators go, the Wx code produced by B<FBP::Perl> is remarkebly
+readable. The produced code can be used either as a starter template which
+you modify, or as a pristine class which you subclass in order to customise.
+
+Born from the L<Padre> Perl IDE project, the code generation API provided by
+B<FBP::Perl> is also extremely amenable to being itself subclassed.
+
+This allows you to relatively easily write customised code generators that
+produce output more closely tailored to your large Wx-based application, or
+to automatically integrate Perl Tidy or other beautifiers into your workflow.
+
+=head1 METHODS
+
 TO BE COMPLETED
 
 =cut
@@ -24,7 +55,7 @@ use warnings;
 use FBP           0.31 ();
 use Data::Dumper 2.122 ();
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 # Event Binding Table
 my %EVENT = (
@@ -591,6 +622,8 @@ sub children_create {
 		if ( $child->isa('FBP::Window') ) {
 			push @windows, $self->window_create($child, $parent);
 		}
+
+		# Descend to child windows
 		next unless $child->does('FBP::Children');
 		if ( $object->isa('FBP::Window') ) {
 			push @windows, $self->children_create($child, $object);
@@ -657,6 +690,8 @@ sub window_create {
 		$lines = $self->staticline_create($window, $parent);
 	} elsif ( $window->isa('FBP::StaticText') ) {
 		$lines = $self->statictext_create($window, $parent);
+	} elsif ( $window->isa('FBP::StatusBar') ) {
+		$lines = $self->statusbar_create($window, $parent);
 	} elsif ( $window->isa('FBP::TextCtrl') ) {
 		$lines = $self->textctrl_create($window, $parent);
 	} else {
@@ -1224,6 +1259,31 @@ sub staticline_create {
 	);
 }
 
+sub statusbar_create {
+	my $self     = shift;
+	my $object   = shift;
+	my $variable = $self->object_variable($object);
+	my $parent   = $self->object_parent(@_);
+	my $fields   = $object->fields;
+	my $id       = $self->wx( $object->id );
+
+	# If the status bar is not stored for later reference,
+	# don't create the variable at all to avoid perlcritic'ism
+	if ( $self->object_lexical($object) ) {
+		$variable = "";
+	} else {
+		$variable = "$variable = ";
+	}
+
+	return $self->nested(
+		"$variable$parent->CreateStatusBar(",
+		"$fields,",
+		$self->window_style($object, 0),
+		"$id,",
+		");",
+	);
+}
+
 sub textctrl_create {
 	my $self      = shift;
 	my $control   = shift;
